skiptools.make_skips_with_multiplied_durations
==============================================

.. autofunction:: abjad.tools.skiptools.make_skips_with_multiplied_durations.make_skips_with_multiplied_durations
